aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--helix-core/src/indent.rs2
-rw-r--r--helix-core/src/syntax.rs6
2 files changed, 3 insertions, 5 deletions
diff --git a/helix-core/src/indent.rs b/helix-core/src/indent.rs
index 83b2be94..ba02065c 100644
--- a/helix-core/src/indent.rs
+++ b/helix-core/src/indent.rs
@@ -433,7 +433,7 @@ where
comment_token: None,
auto_format: false,
diagnostic_severity: Severity::Warning,
- tree_sitter_library: None,
+ grammar: None,
language_server: None,
indent: Some(IndentationConfiguration {
tab_width: 4,
diff --git a/helix-core/src/syntax.rs b/helix-core/src/syntax.rs
index 0f7d224d..038fbfdd 100644
--- a/helix-core/src/syntax.rs
+++ b/helix-core/src/syntax.rs
@@ -108,7 +108,7 @@ pub struct LanguageConfiguration {
#[serde(default)]
pub diagnostic_severity: Severity,
- pub tree_sitter_library: Option<String>, // tree-sitter library name, defaults to language_id
+ pub grammar: Option<String>, // tree-sitter grammar name, defaults to language_id
// content_regex
#[serde(default, skip_serializing, deserialize_with = "deserialize_regex")]
@@ -444,9 +444,7 @@ impl LanguageConfiguration {
} else {
let language = get_language(
&crate::RUNTIME_DIR,
- self.tree_sitter_library
- .as_deref()
- .unwrap_or(&self.language_id),
+ self.grammar.as_deref().unwrap_or(&self.language_id),
)
.map_err(|e| log::info!("{}", e))
.ok()?;